@@ -44,11 +44,11 @@
 #include "kftpsession.h"
 #include "bookmarks/listview.h"
 
-#include "misc/config.h"
+#include "misc/kftpconfig.h"
 #include "engine/thread.h"
 #include "engine/ftpsocket.h"
 
-#include <ntqfile.h>
+#include <tqfile.h>
 
 #include <kdebug.h>
 #include <tdelocale.h>
@@ -808,7 +808,6 @@ void Manager::guiPopulateZeroconfMenu(TDEActionMenu *parentMenu)
   // Clear the menu
   parentMenu->popupMenu()->clear();
 
-#if KDE_IS_VERSION(3,4,0)
   // Populate
   TQValueList<DNSSD::RemoteService::Ptr> list = KFTPAPI::getInstance()->zeroConfInterface()->getServiceList();
 
@@ -826,11 +825,6 @@ void Manager::guiPopulateZeroconfMenu(TDEActionMenu *parentMenu)
     disabledAction->setEnabled(false);
     parentMenu->insert(disabledAction);
   }
-#else
-  TDEAction *disabledAction = new TDEAction(i18n("<DNSSD Not Available>"));
-  disabledAction->setEnabled(false);
-  parentMenu->insert(disabledAction);
-#endif
 }
 
 void Manager::guiPopulateWalletMenu(TDEActionMenu *parentMenu)
@@ -933,13 +927,11 @@ void Manager::slotWalletExecuted()
 
 void Manager::slotZeroconfExecuted()
 {
-#if KDE_IS_VERSION(3,4,0)
   // Get the sender
   KFTPZeroconfAction *action = (KFTPZeroconfAction*) TQObject::sender();
   DNSSD::RemoteService::Ptr service = action->getSite();
 
   KFTPAPI::getInstance()->mainWindow()->slotQuickConnect(service->serviceName(), service->hostName(), service->port());
-#endif
 }
 
 }
