@@ -42,15 +42,15 @@
 
 #include <math.h>
 
-#include <ntqapplication.h>
-#include <ntqbutton.h>
-#include <ntqpopupmenu.h>
-#include <ntqlayout.h>
-#include <ntqpainter.h>
-#include <ntqtooltip.h>
-#include <ntqfontmetrics.h>
-#include <ntqstyle.h>
-#include <ntqtimer.h>
+#include <tqapplication.h>
+#include <tqbutton.h>
+#include <tqpopupmenu.h>
+#include <tqlayout.h>
+#include <tqpainter.h>
+#include <tqtooltip.h>
+#include <tqfontmetrics.h>
+#include <tqstyle.h>
+#include <tqtimer.h>
 
 #include <kiconloader.h>
 #include <kdebug.h>
