@@ -42,7 +42,7 @@
 #include "kftpapi.h"
 #include "queueeditor.h"
 #include "widgets/searchdialog.h"
-#include "misc/config.h"
+#include "misc/kftpconfig.h"
 
 #include <tdeapplication.h>
 #include <tdefiledialog.h>
@@ -55,8 +55,8 @@
 #include <tdelistviewsearchline.h>
 #include <kdebug.h>
 
-#include <ntqspinbox.h>
-#include <ntqtooltip.h>
+#include <tqspinbox.h>
+#include <tqtooltip.h>
 
 using namespace KFTPGrabberBase;
 using namespace KFTPCore;
